=======
History
=======

0.2.0 (2022-11-15)
------------------

* Add the skill extractor.
* Add the salary extractor.
* Add the trained model for salary prediction.
* Add the initial configuration for the skills.

0.1.0 (2022-11-10)
------------------

* First release on PyPI.
